;+
; NAME:
;  oclc_ey92_cseries
; PURPOSE: (one line)
;  return power series in 1/lam used by EY92
; DESCRIPTION:
;  return power series in 1/lam used by EY92
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  cser = oclc_ey92_cseries(order,delta_tau)
; INPUTS:
;  order - order for series
;  delta_tau - H_tau1 r/r_1^2
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  C(delta_tau)
;  Series in delta_tau for use in calculating optical depth
;  Unitless.
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg A7
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_cseries, order, delta_tau

    cser = 1.d

    if order eq 0 then return, cser

    cser = cser + (9./8.) * delta_tau

    if order eq 1 then return, cser

    cser = cser + (345./128.) * (delta_tau ^(2.d))

    if order eq 2 then return, cser

    cser = cser + (9555./1024.) * delta_tau^3.

    if order eq 3 then return, cser

    cser = cser + (1371195./32768.) * delta_tau^4.

    return, cser

end
