;+
; NAME:
;  oclc_ey92_d2t
; PURPOSE: (one line)
;  return temperature second derivative as function of radius
; DESCRIPTION:
;  return temperature second derivative (d^2t/dr^2) as function of radius
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  d2t = oclc_ey92_d2t(r0,lam0, b, Mp, mu0, r)
; INPUTS:
;  r0 - reference radius (scalar, cm)
;  lam0 - reference energy ratio (radius/scale height) (scalar, unitless)
;  b - exponent for non-constant temperature  T(r) = T * (r/r0)^b
;  Mp - planet mass (g). 1.30497e+25 for Pluto (Buie et al 2006)
;  mu0 - reference molecular weight (unitless). 28.01 for Pluto.
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  d2t - second derivative of temperature (K/cm^2) at r
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 3.3
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_d2t, r0,lam0, b, Mp, mu0, r

	t = oclc_ey92_t(r0,lam0, b, Mp, mu0,r)
        d2t = (b * (b-1) /(r^2)) * t
		
    return, d2t

end
