;+
; NAME:
;  oclc_ey92_dt
; PURPOSE: (one line)
;  return temperature gradient as function of radius
; DESCRIPTION:
;  return temperature gradient as function of radius
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  dt = oclc_ey92_dt(r0,lam0, b, Mp, mu0, r)
; INPUTS:
;  r0 - reference radius (scalar, cm)
;  lam0 - reference energy ratio (radius/scale height) (scalar, unitless)
;  b - exponent for non-constant temperature  T(r) = T * (r/r0)^b
;  Mp - planet mass (g). 1.30497e+25 for Pluto (Buie et al 2006)
;  mu0 - reference molecular weight (unitless). 28.01 for Pluto.
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  dt - temperature gradient (K/cm) at r
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 3.3
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_dt, r0,lam0, b, Mp, mu0, r

	t = oclc_ey92_t(r0,lam0, b, Mp, mu0,r)
        dt = (b/r) * t
		
    return, dt

end
