;+
; NAME:
;  oclc_ey92_h
; PURPOSE: (one line)
;  return scale height (H) as a function of radius
; DESCRIPTION:
;  return scale height (H) as a function of radius
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  h = oclc_ey92_h(r0,lam0, a, b, r)
; INPUTS:
;  r0 - reference radius (scalar, cm)
;  lam0 - reference energy ratio (radius/scale height) (scalar, unitless)
;  a - exponent for non-constant mean moleculr weight
;      mu(r) = mu0 * (r/r0)^-a
;  b - exponent for non-constant temperature
;      T(r) = T * (r/r0)^b
;  r - radius at which to evaluat H (scalar or array, cm)
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  H = scale height (cm), defined by
;  H = k T / (mu m_amu g) or
;  - (1/p) dp/dr = 1/H
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 3.21
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_h, r0, lam0, a, b, r

    lam = oclc_ey92_lam(r0, lam0, a, b, r)

	h = r/lam
	
    return, h

end
