;+
; NAME:
;  oclc_ey92_kappa
; PURPOSE: (one line)
;  return kappa as a function of radius
; DESCRIPTION:
;  return kappa (absorption coeffient, cm^-1) as a function of radius
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  kappa = oclc_ey92_kappa(r1, kappa1, htau1, r)
; INPUTS:
;  r1 - top of haze layer
;  kappa1 - linear absorption coefficient at r1
;  htau1 - scale height of absorbtion coefficient
;  r - radius at which to evaluat kappa (scalar or array, cm)
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  kappa (absorption coeffient, cm^-1) at r (planet radius, cm)
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 3.23
; MODIFICATION HISTORY:
;  Written 2006 Aug 17, Leslie Young
;-


function oclc_ey92_kappa, r1, kappa1, htau1, r

    n = n_elements(r)
    kappa = dblarr(n)
    ok = where(r lt r1, nok)  ; ok = list of "OK" = below haze top
    if nok gt 0 then begin
        rok = r[ok]
        kappa[ok] = kappa1 * exp( -(rok-r1)/(htau1 * (rok/r1) ) )
    end

    if n eq 1 and not isarray(rho) then kappa = kappa[0]
    
    return, kappa

end
