;+
; NAME:
;  oclc_ey92_kappa1_of_tauoabs
; PURPOSE: (one line)
;  return kappa1 (linear absorption coefficient at r1) s.t. tauobs(rtau_ref) = tauobs
; DESCRIPTION:
;  return kappa1 (linear absorption coefficient at r1) s.t. tauobs(rtau_ref) = tauobs
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  kappa1 = oclc_ey92_kappa1_of_r2(r1, htau1, r2)
; INPUTS:
;  r1 - top of haze layer
;  htau1 - scale height of absorbtion coefficient
;  r2 - planet radius at which to tauobs = 1 (scalar or array, cm)
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  kappa1 - linear absorption coefficient at r1
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 4.20, 4.21
; MODIFICATION HISTORY:
;  Written 2006 Jun 30, Leslie Young
;-

function oclc_ey92_kappa1_of_r2, r1, htau1, r2

	kappa1 = oclc_ey92_kappa1_of_tauoabs(r1, htau1, r2, 1.d)

    return, kappa1

end
