;+
; NAME:
;  oclc_ey92_kappa1_of_tauoabs
; PURPOSE: (one line)
;  return kappa1 (linear absorption coefficient at r1) s.t. tauobs(rtau_ref) = tauobs
; DESCRIPTION:
;  return kappa1 (linear absorption coefficient at r1) s.t. tauobs(rtau_ref) = tauobs
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  kappa1 = oclc_ey92_kappa1_of_tauoabs(r1, htau1, rtau_ref, tauobs_ref)
; INPUTS:
;  r1 - top of haze layer
;  htau1 - scale height of absorbtion coefficient
;  rtau_ref - radius at which to tauobs = tauobs_ref (scalar or array, cm)
;  tauobs_ref (line-of-sight optical depth, unitless) at rtau_ref
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  kappa1 - linear absorption coefficient at r1
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 4.20, 4.21
; MODIFICATION HISTORY:
;  Written 2006 Jun 30, Leslie Young
;-

function oclc_ey92_kappa1_of_tauoabs, r1, htau1, rtau_ref, tauobs_ref

	tau2_kappa_eq_1 = oclc_ey92_tauobs(r1, 1.d , htau1, rtau_ref)

	kappa1 = tauobs_ref / tau2_kappa_eq_1

    return, kappa1

end
