;+
; NAME:
;  oclc_ey92_n
; PURPOSE: (one line)
;  return n (number density) as a function of radius
; DESCRIPTION:
;  return n as a function of radius
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  n = oclc_ey92_n(r0,nu0,lam0,a,b,nustp, r)
; INPUTS:
;  r0 - reference radius (scalar, cm)
;  nu0 - refractivity at r0 (scalar, unitless)
;  lam0 - reference energy ratio (radius/scale height) (scalar, unitless)
;  a - exponent for non-constant mean moleculr weight
;      mu(r) = mu0 * (r/r0)^-a
;  b - exponent for non-constant temperature
;      T(r) = T * (r/r0)^b
;  r - planet radius at which to evaluate nu (scalar or array, cm)
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  nu (refractivity, unitless) at r (planet radius, cm)
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 3.20, 3.18
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_n, r0, nu0, lam0, a, b, nustp, r

	nu = oclc_ey92_nu(r0,nu0,lam0,a,b, r)

	physconstants ; define !phys

	loschmidt = 1.01325e6/(!phys.k * 273.15)

	n = (nu / nustp) * loschmidt
    return, n

end
