;+
; NAME:
;  oclc_ey92_n0
; PURPOSE: (one line)
;  return reference number density
; DESCRIPTION:
;  return reference number density
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  n0 = oclc_ey92_n0(nu0, nustp)
; INPUTS:
;  nu0 - reference refractivity (scalar, cm)
;  nustp - refractivity at STP (273.15 K, 1.013250e6 microsbar). 2.98e-4 for Pluto.
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  n0 - number density (cm^-3) at r0
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 3.18
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_n0, nu0, nustp

	physconstants ; define !phys

	loschmidt = 1.01325e6/(!phys.k * 273.15)

	n0 = (nu0 / nustp) * loschmidt
    return, n0

end
