;+
; NAME:
;  oclc_ey92_p
; PURPOSE: (one line)
;  return pressure as a function of radius
; DESCRIPTION:
;  return pressure as a function of radius
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  p = oclc_ey92_p(r0, nu0, lam0, a, b, mp, mu0, nustp, r)
; INPUTS:
;  r0 - reference radius (scalar, cm)
;  nu0 - refractivity at r0 (scalar, unitless)
;  lam0 - reference energy ratio (radius/scale height) (scalar, unitless)
;  a - exponent for non-constant mean moleculr weight: mu(r) = mu0 * (r/r0)^-a
;  b - exponent for non-constant temperature; T(r) = T * (r/r0)^b
;  Mp - planet mass (g). 1.30497e+25 for Pluto (Buie et al 2006)
;  mu0 - molecular weight (unitless). 28.01 for Pluto.
;  nustp - refractivity at STP (273.15 K, 1.013250e6 microsbar). 2.98e-4 for Pluto.
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  p0 - pressure (microbar) at r0
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 3.6
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-

function oclc_ey92_p, r0, nu0, lam0, a, b, mp, mu0, nustp, r

    physconstants               ; define !phys

    n = oclc_ey92_n(r0,nu0,lam0,a,b,nustp, r)
    t = oclc_ey92_t(r0,lam0, b, Mp, mu0, r)
    
    p = !phys.k * t * n
    
    return, p
	
end
