;+
; NAME:
;  oclc_ey92_p0
; PURPOSE: (one line)
;  return reference pressure
; DESCRIPTION:
;  return reference pressure
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  p0 = oclc_ey92_p0(r0, nu0, lam0, mp, mu0, nustp)
; INPUTS:
;  r0 - reference radius (scalar, cm)
;  nu0 - refractivity at r0 (scalar, unitless)
;  lam0 - reference energy ratio (radius/scale height) (scalar,
;         unitless)
;  Mp - planet mass (g). 1.30497e+25 for Pluto (Buie et al 2006)
;  mu0 - molecular weight (unitless). 28.01 for Pluto.
;  nustp - refractivity at STP (273.15 K, 1.013250e6 microsbar). 2.98e-4 for Pluto.
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  p0 - pressure (microbar) at r0
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 3.18
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_p0, r0, nu0, lam0, mp, mu0, nustp

	physconstants ; define !phys

	n0 = oclc_ey92_n0(nu0, nustp)
	t0 = oclc_ey92_t0(r0,lam0, Mp, mu0)
	
	p0 = !phys.k * t0 * n0
	
	return, p0
	
end
