;+
; NAME:
;  oclc_ey92_rho_of_r
; PURPOSE: (one line)
;  return r (planet radius) as a function of rho (shadow radius)
; DESCRIPTION:
;  return r as a function of rho
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  rho = oclc_ey92_rho_of_r(r0,nu0,lam0,a,b, dist, order, r)
; INPUTS:
;  r0 - reference radius (scalar, cm)
;  nu0 - refractivity at r0 (scalar, unitless)
;  lam0 - reference energy ratio (radius/scale height) (scalar, unitless)
;  a - exponent for non-constant mean moleculr weight
;      mu(r) = mu0 * (r/r0)^-a
;  b - exponent for non-constant temperature
;      T(r) = T * (r/r0)^b
;  dist - planet-observer distance (scalar, cm)
;  order - order of expansion for series
;  r - planet radius (cm)
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  rho at r
;  rho - shadow radius at  r (scalar or array, cm),
;        negative for far-limb contribution; COMMON BLOCKS:
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 2.2
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_rho_of_r, r0, nu0, lam0, a, b, dist, order, r

    theta = oclc_ey92_theta(r0, nu0, lam0, a, b, order, r)
    rho = r + dist * theta

    return, rho

end
