;+
; NAME:
;  oclc_ey92_rho_of_time
; PURPOSE: (one line)
;  return rho (shadow radius) as a function of time assuming linear motion
; DESCRIPTION:
;  return rho as a function of time
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  rho = oclc_ey92_rho_of_time(rhomid, timemid, v, time)
; INPUTS:
;  rhomin - shadow radius at midtime (cm)
;  timemid - mid time (s)
;  v - sky-plane velocity, cm/s
;  time - time (s) at which to evaluate rho
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  rho - shadow radius 
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 5.1
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_rho_of_time, rhomin, timemid, v, time

    rho = sqrt( rhomin^2 + (v * (time - timemid))^2 )

    return, rho

end
