;+
; NAME:
;  oclc_ey92_t
; PURPOSE: (one line)
;  return temperature as function of radius
; DESCRIPTION:
;  return temperature as function of radius
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  t = oclc_ey92_t(r0,lam0, b, Mp, mu0, r)
; INPUTS:
;  r0 - reference radius (scalar, cm)
;  lam0 - reference energy ratio (radius/scale height) (scalar, unitless)
;  b - exponent for non-constant temperature  T(r) = T * (r/r0)^b
;  Mp - planet mass (g). 1.30497e+25 for Pluto (Buie et al 2006)
;  mu0 - reference molecular weight (unitless). 28.01 for Pluto.
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  t - temperature (K) at r
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 3.3
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_t, r0,lam0, b, Mp, mu0, r

	t0 = oclc_ey92_t0(r0,lam0, Mp, mu0)
	t = t0 * (r/r0)^b
		
    return, t

end
