;+
; NAME:
;  oclc_ey92_t0
; PURPOSE: (one line)
;  return reference temperature
; DESCRIPTION:
;  return reference temperature
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  t0 = oclc_ey92_t0(r0,lam0, Mp, mu0)
; INPUTS:
;  r0 - reference radius (scalar, cm)
;  lam0 - reference energy ratio (radius/scale height) (scalar, unitless)
;  Mp - planet mass (g). 1.30497e+25 for Pluto (Buie et al 2006)
;  mu0 - molecular weight (unitless). 28.01 for Pluto.
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  t0 - temperature (K) at r0
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 3.10
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_t0, r0,lam0, Mp, mu0

	physconstants ; define !phys

	t0 = !phys.g * mp * mu0 * !phys.m_u / (lam0 * !phys.k * r0)
	
    return, t0

end
