;+
; NAME:
;  oclc_ey92_table3a
; PURPOSE: (one line)
;  reproduce table 3a
; DESCRIPTION:
;  reproduce table 3a
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  oclc_ey92_table3a, time, rho, r, lam, nu, kappa, tauobs, phi_cyl,
;  phi_ref, phi
; INPUTS:
;  none
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  time - time
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 3.18
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-

pro oclc_ey92_table3a, order, b


    km = 1d5
    au = 149597870.691d * km
    
    v = 18.5d * km
    dist = 28.89675d * au

    r0 = 1250.d * km

    dataparm = 1
    if (dataparm) then begin
                                ; values from Table 2
        f = 0.5d
        timeim =  53.9d
        timeem = 139.9d
        timehiso = 4.7d
        a = 0.d
        timeh1 = 4.2d
        timeh2 = 7.0d
        timehtau2 = 2.3d
        timemin = 46.9d
        
        r0 = 1250.d * km

        oclc_ey92_atmparam, v, dist, f, r0, order,$
          timeim, timeem, timehiso, a, b,timeh1, timeh2, timehtau2, timemin, $
          timemid, rhomin, nu0, lam0, r1, kappa1, htau1, $
          rhof = rhof, r2 = r2


        print, 'timemid ',  timemid,   form='(A14,F5.1)'
        print, 'rhomin',    rhomin/km, form='(A14,F10.2)'
        print, 'nu0 * 1e9', nu0 * 1e9, form='(A14,F10.6)'
        print, 'lam0',      lam0,      form='(A14,F10.5)'
        print, 'r1',        r1/km,     form='(A14,F10.3)'
        print, 'kappa1 * 1e8', kappa1 * 1e8, form='(A14,F10.6)'
        print, 'Htau11',    htau1/km,  form='(A14,F10.5)'

    endif else begin
        timemid = 96.9d
        rhomin = 867.65d * km
        b = 0.d
        a = 0.d
        case order of
            0: begin
                nu0 = 1.152234d-9
                lam0 = 21.01520d
                r1 = 1221.175e5
                kappa1 = 2.351658d-8
                htau1 = 29.28378d5
            end
            1: begin
                nu0 = 1.111036d-9
                lam0 = 20.95764d
                r1 = 1219.194e5
                kappa1 = 2.271510d-8
                htau1 = 29.29109d5
            end
            4: begin
                nu0 = 1.110238d-9
                lam0 = 20.95657d
                r1 = 1219.158e5
                kappa1 = 2.267495d-8
                htau1 = 29.29122d5
            end
        endcase
    endelse

    time = dindgen(11) * 5.d + 30

    ; calculate rho
        
    rho = sqrt( ( v * (time-timemid))^2 + rhomin^2)
    
    r = oclc_ey92_r_of_rho(r0,nu0,lam0,a,b, dist, order, rho)
    lam = oclc_ey92_lam(r0,lam0,a,b, r)
    nu = oclc_ey92_nu(r0,nu0,lam0,a,b, r)
    kappa = oclc_ey92_kappa(r1, kappa1, htau1, r)
    tauobs = oclc_ey92_tauobs(r1, kappa1, htau1, order, r)
    dtheta = oclc_ey92_dtheta(r0,nu0,lam0,a,b, order, r)
    phi_cyl = (1./abs(1+dist*dtheta))
    phi_ref = oclc_ey92_phi_of_r(r0, nu0, lam0, a, b, r1, kappa1*0, htau1, dist, 1000.e5, order, r)
    phi    = oclc_ey92_phi_of_r(r0, nu0, lam0, a, b, r1, kappa1, htau1, dist, 1000.e5, order, r)

    
    forprint,    time, rho/km, r/km, lam, nu/1e-9, kappa * 1e8, tauobs, phi_cyl, phi_ref, phi, $
      format = '(F3.0,  F10.4, F10.4, F10.5, E15.6, E15.6, E15.6, 3F10.7)'


    rr = r[6:10]
    k = kappa1 * exp( -(rr - r1)/( htau1 * (rr/r1) ) )  
    kappa1pub = 2.351658d-8
    k2 = [3.068288, 5.426357d, 8.306413, 11.42810, 14.46230] * 1d-8

end
